==> ambition_ae-0.3.17-py3-none-any.whl: ambition_ae/admin/ae_susar_admin.py <==
from django.contrib import admin
from edc_action_item import action_fieldset_tuple
from edc_model_admin import audit_fieldset_tuple, SimpleHistoryAdmin

from ..admin_site import ambition_ae_admin
from ..forms import AeSusarForm
from ..models import AeSusar
from .modeladmin_mixins import ModelAdminMixin, NonAeInitialModelAdminMixin


@admin.register(AeSusar, site=ambition_ae_admin)
class AeSusarAdmin(ModelAdminMixin, NonAeInitialModelAdminMixin, SimpleHistoryAdmin):

    form = AeSusarForm

    # additional_instructions = "For completion by TMG Investigators Only"
    # subject_dashboard_url = "susar_ae_listboard_url"

    list_display = [
        "subject_identifier",
        "dashboard",
        "status",
        "ae_initial",
        "report_datetime",
        "submitted_datetime",
    ]

    list_filter = ("report_datetime", "submitted_datetime")

    search_fields = [
        "subject_identifier",
        "action_identifier",
        "ae_initial__action_identifier",
        "ae_initial__tracking_identifier",
        "tracking_identifier",
    ]

    fieldsets = (
        (
            None,
            {
                "fields": (
                    "subject_identifier",
                    "ae_initial",
                    "report_datetime",
                    "submitted_datetime",
                )
            },
        ),
        action_fieldset_tuple,
        audit_fieldset_tuple,
    )

    radio_fields = {"report_status": admin.VERTICAL}

    def status(self, obj=None):
        return obj.report_status.title()

==> ambition_ae-0.3.20-py3-none-any.whl: ambition_ae/admin/ae_susar_admin.py <==
from django.contrib import admin
from edc_action_item import action_fieldset_tuple
from edc_model_admin import audit_fieldset_tuple, SimpleHistoryAdmin
from edc_model_admin.dashboard import ModelAdminSubjectDashboardMixin

from ..admin_site import ambition_ae_admin
from ..forms import AeSusarForm
from ..models import AeSusar
from .modeladmin_mixins import NonAeInitialModelAdminMixin


@admin.register(AeSusar, site=ambition_ae_admin)
class AeSusarAdmin(
    ModelAdminSubjectDashboardMixin, NonAeInitialModelAdminMixin, SimpleHistoryAdmin
):

    form = AeSusarForm

    # additional_instructions = "For completion by TMG Investigators Only"
    # subject_dashboard_url = "susar_ae_listboard_url"

    list_display = [
        "subject_identifier",
        "dashboard",
        "status",
        "ae_initial",
        "report_datetime",
        "submitted_datetime",
    ]

    list_filter = ("report_datetime", "submitted_datetime")

    search_fields = [
        "subject_identifier",
        "action_identifier",
        "ae_initial__action_identifier",
        "ae_initial__tracking_identifier",
        "tracking_identifier",
    ]

    fieldsets = (
        (
            None,
            {
                "fields": (
                    "subject_identifier",
                    "ae_initial",
                    "report_datetime",
                    "submitted_datetime",
                )
            },
        ),
        action_fieldset_tuple,
        audit_fieldset_tuple,
    )

    radio_fields = {"report_status": admin.VERTICAL}

    def status(self, obj=None):
        return obj.report_status.title()
